@@ -1,44 +1,29 @@
-#######################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Test-Perl-Critic/lib/Test/Perl/Critic.pm $
-#     $Date: 2005-12-29 21:11:29 -0800 (Thu, 29 Dec 2005) $
-#   $Author: thaljef $
-# $Revision: 178 $
-########################################################################
-
 package Test::Perl::Critic;
 
 use strict;
 use warnings;
-use English qw(-no_match_vars);
 use Test::Builder;
 use Perl::Critic;
 use File::Spec;
 
-our $VERSION = '0.03_01';
+our $VERSION = '0.02';
 $VERSION = eval $VERSION;    ## no critic
 
-my $TEST     = Test::Builder->new();
-my $PROFILE  = undef;
-my $FORMAT   = undef;
-my $SEVERITY = undef;
+my $TEST   = Test::Builder->new();
+my $CONFIG = undef;
 
 #---------------------------------------------------------------------------
 
 sub import {
-
     my ( $self, %args ) = @_;
     my $caller = caller;
 
-    no strict 'refs';  ## no critic
+    no strict 'refs';
     *{ $caller . '::critic_ok' }     = \&critic_ok;
     *{ $caller . '::all_critic_ok' } = \&all_critic_ok;
 
     $TEST->exported_to($caller);
-    $FORMAT   = $args{-format}   || "\t%m at line %l, column %c. %e";
-    $PROFILE  = $args{-profile}  || q{};
-    $SEVERITY = $args{-severity} || 1;
-
-    return 1;
+    $CONFIG = $args{-profile};
 }
 
 #---------------------------------------------------------------------------
@@ -46,41 +31,23 @@ sub import {
 sub critic_ok {
 
     my ( $file, $name ) = @_;
-    $name ||= qq{Test::Perl::Critic for '$file'};
-    my @violations = ();
-    my $ok = 0;
+    $name ||= "Test::Perl::Critic for $file";
 
     if ( !-f $file ) {
         $TEST->ok( 0, $name );
-        $TEST->diag( qq{'$file' does not exist} );
+        $TEST->diag("$file does not exist");
         return;
     }
 
-    eval {
-        my %config  = ( -severity => $SEVERITY, -profile => $PROFILE );
-	my $critic  = Perl::Critic->new( %config );
-	@violations = $critic->critique($file);
-	$ok         = !scalar @violations;
-    };
-
-    # Evaluate results
+    my $critic     = Perl::Critic->new( -profile => $CONFIG );
+    my @violations = $critic->critique($file);
+    my $ok         = !scalar @violations;
     $TEST->ok( $ok, $name );
 
-
-    if ($EVAL_ERROR) {     # Trap exceptions from P::C
-	$TEST->diag( "\n" );     #Just to get on a new line.
-        $TEST->diag( qq{Perl::Critic had errors in '$file':} );
-	$TEST->diag( qq{\t$EVAL_ERROR} );
-    }
-    elsif ( !$ok ) {    # Report Policy violations
-        $TEST->diag( "\n" );         #Just to get on a new line.
-        $TEST->diag( qq{Perl::Critic found these violations in '$file':} );
-	$FORMAT =~ s{\%f}{$file}gmx; #HACK! Violation doesn't know the file
-
-        ## no critic
-	no warnings 'once';
-	local $Perl::Critic::Violation::FORMAT = $FORMAT;
-        for my $viol (@violations) { $TEST->diag("$viol") }
+    if ( !$ok ) {
+        $TEST->diag('####');    #Just to get on a new line.
+        $TEST->diag("Perl::Critic found these violations in $file:");
+        for my $line (@violations) { $TEST->diag("\t$line") }
     }
 
     return $ok;
@@ -115,8 +82,9 @@ sub all_code_files {
             closedir $dh;
 
             @newfiles = File::Spec->no_upwards(@newfiles);
-            @newfiles = grep { $_ ne 'CVS' && $_ ne '.svn' }    @newfiles;
-            push @queue, map { File::Spec->catfile($file, $_) } @newfiles;
+            @newfiles = grep { $_ ne 'CVS' && $_ ne '.svn' } @newfiles;
+
+            push @queue, map { "$file/$_" } @newfiles;
         }
 
         if ( -f $file && _is_perl($file) ) {
@@ -137,16 +105,16 @@ sub _is_perl {
     my $file = shift;
 
     #Check filename extensions
-    return 1 if $file =~ m{ [.] PL          \z}mx;
-    return 1 if $file =~ m{ [.] p (?: l|m ) \z}mx;
-    return 1 if $file =~ m{ [.] t           \z}mx;
+    return 1 if $file =~ /\.PL$/;
+    return 1 if $file =~ /\.p(l|m)$/;
+    return 1 if $file =~ /\.t/;
 
     #Check for shebang
-    open my ($fh), '<', $file or return;
+    open my ($fh), $file or return;
     my $first = <$fh>;
     close $fh;
 
-    return 1 if defined $first && ( $first =~ m{ \A \#!.*perl }mx );
+    return 1 if defined $first && ( $first =~ /^#!.*perl/ );
     return;
 }
 
@@ -224,7 +192,7 @@ A Perl file is:
 
 =head1 CONFIGURATION
 
-L<Perl::Critic> is highly configurable.  By default, Test::Perl::Critic
+L<Perl::Crtic> is highly configurable.  By default, Test::Perl::Critic
 invokes Perl::Critic with its default configuration.  But if you have
 developed your code against a custom Perl::Critic configuration,
 you will want to configure Test::Perl::Critic to do the same.
@@ -239,52 +207,7 @@ Now place a copy of your own F<.perlcritic> file in the distribution
 as F<t/perlcriticrc>.  Then, C<critc_ok()> will be run on all Perl
 files in this distribution using this same Perl::Critic configuration.
 See the L<Perl::Critic> documentation for details on the
-F<.perlcriticrc> file format.
-
-=head1 DIAGNOSTIC DETAILS
-
-By default, Test::Perl::Critic displays basic information about each
-Policy violation in the diagnostic output of the test.  You can
-customize the format and content of this information by giving the
-C<-format> option to the C<use> pragma.  For example:
-
-  use Test::Perl::Critic (-format => "%m at line %l, column %c.");
-  all_critic_ok();
-
-Formats are a combination of literal and escape characters similar to
-the way C<sprintf> works.  See L<String::Format> for a full
-explanation of the formatting capabilities.  Valid escape characters
-are:
-
-  Escape    Meaning
-  -------   ------------------------------------------------------------------
-  %m        Brief description of the violation
-  %f        Name of the file where the violation occurred.
-  %l        Line number where the violation occurred
-  %c        Column number where the violation occurred
-  %e        Explanation of violation or page numbers in PBP
-  %d        Full diagnostic discussion of the violation
-  %r        The string of source code that caused the violation
-  %p        Name of the Policy module that created the violation
-  %s        The severity level of the violation
-
-=head1 CAVEATS
-
-Despite the obvious convenience of using test scripts to verify that
-your code complies with coding standards, its not really sesible to
-distribute your module with those scripts.  You don't know which
-version of Perl::Critic the user has and whether they have installed
-additional Policy modules, you can't really be sure that your code
-will pass the Test::Perl::Critic tests on another machine.
-
-The easy solution is to add your F<criticize.t> test script to the
-F<MANIFEST.SKIP>.  When you test your build, you'll still be able to
-run the Perl::Critic tests when you C<'make test'>, but they won't be
-included in the tarball when you C<'make dist'>.
-
-See L<http://www.chrisdolan.net/talk/index.php/2005/11/14/private-regression-tests/>
-for an interesting discussion about Test::Perl::Critic and other types
-of author-only regression tests.
+F<.perlcriticrc> file format..
 
 =head1 EXPORTS
 
